@@ -7,7 +7,7 @@ use warnings;
 
 require Exporter;
 
-our $VERSION  = "0.08";
+our $VERSION  = "0.13";
 
 our @ISA = qw(Exporter);
 
@@ -43,14 +43,14 @@ Crypt::OpenSSL::SignCSR - Sign a Certificate Signing Request in XS.
                                     format  => $format, # Output format "text" or "pem" (default)
                                 });
   my $cert   = $signer->sign(
-                                $request, # CRS in PEM format
+                                $request, # CSR in PEM format
                             );
 
   my $ret = $signer->set_days(3650);
   my $ret = $signer->set_format("text");
   my $ret = $signer->set_days("SHA512");
 
-  $cert   = $signer->sign( $request ); # CRS in PEM format
+  $cert   = $signer->sign( $request ); # CSR in PEM format
 
 =head1 DESCRIPTION
 
@@ -122,7 +122,7 @@ Arguments:
 
 Get the number of days that is currently set.
 
-Returns a number
+Returns the number of days or -1 for a failure.
 
 =head1 EXPORT
 
